Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckPassword ¶
func HashPassword ¶
GeneratePasswordHash generates a password hash using the bcrypt algorithm
func RandomEmail ¶
func RandomEmail() string
func RandomString ¶
Types ¶
type Config ¶
type Config struct {
DBDriver string `mapstructure:"DB_DRIVER"`
DBSource string `mapstructure:"DB_SOURCE"`
ServerAddress string `mapstructure:"SERVER_ADDRESS"`
Environment string `mapstructure:"ENVIRONMENT"`
TokenSymmetricKey string `mapstructure:"TOKEN_SYMMETRIC_KEY"`
AccessTokenDuration time.Duration `mapstructure:"ACCESS_TOKEN_DURATION"`
}
Config struct for the app.env file
func LoadConfig ¶
Load app.env file, this file is set as environment variables in container
Click to show internal directories.
Click to hide internal directories.